@@ -47,7 +47,7 @@ class Indexer:
         for control,value in kwargs.items():
             self.properties.put(control,value)
 
-    def checkIndexExists():
+    def checkIndexExists(self):
         if os.path.isfile(self.path):
             if not self.overwrite :
                 raise ValueError("Index already exists at " + self.path)
@@ -96,7 +96,7 @@ class DFIndexer(Indexer):
     Use for Pandas dataframe
     '''
     def index(self, text, *args, **kwargs):
-        checkIndexExists()
+        self.checkIndexExists()
         self.index_called=True
         all_metadata={}
         for arg in args:
@@ -139,7 +139,7 @@ class TRECCollectionIndexer(Indexer):
     Use for TREC formatted collection
     '''
     def index(self, files_path):
-        checkIndexExists()
+        self.checkIndexExists()
         self.index_called=True
         index = self.createIndexer()
         asList = self.createAsList(files_path)
@@ -152,7 +152,7 @@ class FilesIndexer(Indexer):
     Use for pdf, docx, txt etc files
     '''
     def index(self, files_path):
-        checkIndexExists()
+        self.checkIndexExists()
         self.index_called=True
         index = self.createIndexer()
         asList = self.createAsList(files_path)
